from setuptools import setup

setup(name='mlfc_distributions',
      version='1.3',
      description='Gaussian distributions',
      packages=['mlfc_distributions'],
      author='RK',
      author_email='rom@mailinator.com',
      url='https://udacity.com',
      zip_safe=False)
